import React from 'react';
import { Meta } from '@storybook/react/types-6-0';
import { Story } from '@storybook/react';
import Button, { ButtonProps } from './Button';

const variants = ['primary', 'secondary', 'danger'];
const sizes = ['xs', 'sm', 'md', 'lg'];
const fills = ['solid', 'border', 'text'];
const stupidLabels = [
  'plsplsplsplsplsplsplsplsplsplspls',
  'pls abc123 pls abc123 pls abc123 pls abc123 pls abc123 pls abc123 pls abc123 ',
];

export default {
  title: 'Components/Button',
  component: Button,
  parameters: {
    docs: {
      inlineStories: true,
    },
  },
} as Meta;

export const Default = (args: ButtonProps) => <Button {...args} />;
Default.args = {
  variant: 'primary',
  size: 'lg',
  label: `hi mum`,
};

export const AllTypes = () => (
  <div
    style={{
      display: 'grid',
      gridGap: '10px',
      gridTemplateColumns: `repeat(${variants.length}, auto)`,
      justifyItems: 'start',
      alignItems: 'center',
      gridAutoFlow: 'column',
    }}
  >
    {sizes.map((size, sizeIndex) =>
      variants.map((variant) =>
        fills.map((fill) => (
          <React.Fragment key={`${size}-${variant}-${fill}`}>
            <Button
              style={{ gridColumn: sizeIndex + 1 }}
              size={size as any}
              variant={variant as any}
              fill={fill as any}
              disabled={false}
              label={`${variant} ${fill}`}
              uppercase
            />
          </React.Fragment>
        ))
      )
    )}
  </div>
);

export const AllTypesDisabled = () => (
  <div
    style={{
      display: 'grid',
      gridGap: '10px',
      gridTemplateColumns: `repeat(${variants.length}, auto)`,
      justifyItems: 'start',
      alignItems: 'center',
      gridAutoFlow: 'column',
    }}
  >
    {sizes.map((size, sizeIndex) =>
      variants.map((variant) =>
        fills.map((fill) => (
          <React.Fragment key={`${size}-${variant}-${fill}`}>
            <Button
              style={{ gridColumn: sizeIndex + 1 }}
              size={size as any}
              variant={variant as any}
              fill={fill as any}
              disabled={true}
              label={`${variant} ${fill}`}
              uppercase
            />
          </React.Fragment>
        ))
      )
    )}
  </div>
);

export const AllTypesLoading = () => (
  <div
    style={{
      display: 'grid',
      gridGap: '10px',
      gridTemplateColumns: `repeat(${variants.length}, auto)`,
      justifyItems: 'start',
      alignItems: 'center',
      gridAutoFlow: 'column',
    }}
  >
    {sizes.map((size, sizeIndex) =>
      variants.map((variant) =>
        fills.map((fill) => (
          <React.Fragment key={`${size}-${variant}-${fill}`}>
            <Button
              style={{ gridColumn: sizeIndex + 1 }}
              size={size as any}
              variant={variant as any}
              fill={fill as any}
              label={`${variant} ${fill}`}
              uppercase
              loading
            />
          </React.Fragment>
        ))
      )
    )}
  </div>
);

export const AllTypesLoadingAndDisabled = () => (
  <div
    style={{
      display: 'grid',
      gridGap: '10px',
      gridTemplateColumns: `repeat(${variants.length}, auto)`,
      justifyItems: 'start',
      alignItems: 'center',
      gridAutoFlow: 'column',
    }}
  >
    {sizes.map((size, sizeIndex) =>
      variants.map((variant) =>
        fills.map((fill) => (
          <React.Fragment key={`${size}-${variant}-${fill}`}>
            <Button
              style={{ gridColumn: sizeIndex + 1 }}
              size={size as any}
              variant={variant as any}
              fill={fill as any}
              disabled={true}
              label={`${variant} ${fill}`}
              uppercase
              loading
            />
          </React.Fragment>
        ))
      )
    )}
  </div>
);

export const StupidLabelledBtns = () => (
  <div
    style={{
      display: 'grid',
      gridGap: '10px',
      gridTemplateColumns: `repeat(${variants.length}, auto)`,
      justifyItems: 'start',
      alignItems: 'center',
      gridAutoFlow: 'column',
    }}
  >
    {stupidLabels.map((label) =>
      sizes.map((size, sizeIndex) =>
        fills.map((fill) => (
          <React.Fragment key={`${size}-${fill}`}>
            <Button
              style={{ gridColumn: sizeIndex + 1 }}
              size={size as any}
              variant="primary"
              fill={fill as any}
              label={` ${label}`}
              uppercase
            />
          </React.Fragment>
        ))
      )
    )}
  </div>
);
