import React, {
  InputHTMLAttributes,
  LabelHTMLAttributes,
  HTMLAttributes,
} from 'react';
import tw, { styled, css } from 'twin.macro';

// export interface InputContainerProps {
//   /** pls provide button children */
//   children: React.ReactChild | React.ReactChild[];
// }

export interface StyledContainerProps extends HTMLAttributes<HTMLDivElement> {
  border?: 'bottom | full';
}

export interface TextInputContainerProps
  extends InputHTMLAttributes<HTMLInputElement> {
  name?: string;
  id?: string;
}

export interface LabelProps extends LabelHTMLAttributes<HTMLInputElement> {
  label?: string;
}

const StyledContainer = styled.div(({}: any) => [
  tw`
relative border-b-2 focus-within:border-blue-400
`,
]);

const TextInputContainer = styled.input(({}: TextInputContainerProps) => [
  tw`
  block w-full appearance-none focus:outline-none bg-transparent
  focus-within:[~ label]:(transform scale-75 -translate-y-6 text-blue-400)
  [:not(:placeholder-shown)~ label]:(transform scale-75 -translate-y-6)
  `,
]);

const Label = styled.label(({}: LabelProps) => [
  tw`absolute top-0 -z-10 duration-300 origin-0`,
]);

const InputContainer = (
  props: StyledContainerProps & TextInputContainerProps & LabelProps
) => (
  <>
    {/** gotta add other types just testing with text for now */}
    {props.type === 'text' ? (
      <StyledContainer>
        <TextInputContainer
          id={props.id}
          name={props.id}
          {...props}
          placeholder=""
        />
        <Label htmlFor={props.id}>{props.label}</Label>
      </StyledContainer>
    ) : (
      <>
        <input id={props.id} name={props.id} type={props.type} {...props} />
        <label htmlFor={props.id}></label>
      </>
    )}
  </>
);

InputContainer.defaultProps = {
  border: 'bottom',
};

export default InputContainer;
